expr! procedural macro for zenith-float.
Depend on the zenith-float crate and use zenith_float::expr. This crate is not a direct dependency for applications.
expr! procedural macro for zenith-float.
Depend on the zenith-float crate and use zenith_float::expr. This crate is not a direct dependency for applications.