exact!() { /* proc-macro */ }Expand description
Compile-time decimal float literal.
Parses a string literal at compile time and expands to an exact ExactNum.
Use via the zenith-float crate: use zenith_float::exact.
exact!() { /* proc-macro */ }Compile-time decimal float literal.
Parses a string literal at compile time and expands to an exact ExactNum.
Use via the zenith-float crate: use zenith_float::exact.